==> haskell-safecopy-0.9.3.1-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-safecopy.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: safecopy
version: 0.9.3.1
id: safecopy-0.9.3.1-JhyFkC4ReLvG3pRzR2XwSJ
key: safecopy-0.9.3.1-JhyFkC4ReLvG3pRzR2XwSJ
license: PublicDomain
maintainer: Lemmih <lemmih@gmail.com>
homepage: https://github.com/acid-state/safecopy
synopsis: Binary serialization with version control.
description:
    An extension to Data.Serialize with built-in version control.
category: Data, Parsing
author: David Himmelstrup, Felipe Lessa
exposed: True
exposed-modules:
    Data.SafeCopy Data.SafeCopy.Internal
hidden-modules: Data.SafeCopy.Instances Data.SafeCopy.SafeCopy
                Data.SafeCopy.Derive
abi: 3c170f7eb2d6195e095469f2ddf4a32a
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/safecopy-0.9.3.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/safecopy-0.9.3.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/safecopy-0.9.3.1
hs-libraries: HSsafecopy-0.9.3.1-JhyFkC4ReLvG3pRzR2XwSJ
depends:
    array-0.5.1.1 base-4.9.0.0 bytestring-0.10.8.1
    cereal-0.5.4.0-1RWVeyNi1If1ir8gxayRPi containers-0.5.7.1
    old-time-1.1.0.3-IcvdkJUsE9M8t3io8peAEp template-haskell-2.11.0.0
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ time-1.6.0.1
    vector-0.11.0.0-BEDZb5o2QOhGbIm6ky7rl6
haddock-interfaces: /usr/share/doc/haskell-safecopy/html/safecopy.haddock
haddock-html: /usr/share/doc/haskell-safecopy/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-safecopy-0.9.3.1-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-safecopy.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: safecopy
version: 0.9.3.1
id: safecopy-0.9.3.1-3kmdSnd9TxSGD9A8MvyrZm
key: safecopy-0.9.3.1-3kmdSnd9TxSGD9A8MvyrZm
license: PublicDomain
maintainer: Lemmih <lemmih@gmail.com>
homepage: https://github.com/acid-state/safecopy
synopsis: Binary serialization with version control.
description:
    An extension to Data.Serialize with built-in version control.
category: Data, Parsing
author: David Himmelstrup, Felipe Lessa
exposed: True
exposed-modules:
    Data.SafeCopy Data.SafeCopy.Internal
hidden-modules: Data.SafeCopy.Instances Data.SafeCopy.SafeCopy
                Data.SafeCopy.Derive
abi: ba3b9b9193b5399006ef51832b675f52
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/safecopy-0.9.3.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/safecopy-0.9.3.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/safecopy-0.9.3.1
hs-libraries: HSsafecopy-0.9.3.1-3kmdSnd9TxSGD9A8MvyrZm
depends:
    array-0.5.1.1 base-4.9.0.0 bytestring-0.10.8.1
    cereal-0.5.4.0-1RWVeyNi1If1ir8gxayRPi containers-0.5.7.1
    old-time-1.1.0.3-IcvdkJUsE9M8t3io8peAEp template-haskell-2.11.0.0
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ time-1.6.0.1
    vector-0.12.0.1-FyKxZ6HyOdr5RycjHR2p0f
haddock-interfaces: /usr/share/doc/haskell-safecopy/html/safecopy.haddock
haddock-html: /usr/share/doc/haskell-safecopy/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
